@@ -298,7 +298,7 @@ TEST(ParserTest, file) {
     configs.push_back("sample1.json");
     configs.push_back("template.json");
 
-    for (int i = 0; i<configs.size(); i++) {
+    for (size_t i = 0; i < configs.size(); ++i) {
         testFile(string(CFG_EXAMPLES) + "/" + configs[i]);
     }
 }
@@ -861,7 +861,22 @@ TEST_F(TrailingCommasTest, tests) {
         "name": "d2.md5.key",
         "secret": "sensitivejdPJI5QxlpnfQ==",
       },
-    ]
+    ],
+    "control-sockets": [
+      {
+        "socket-type": "http",
+        "socket-address": "::1",
+        "authentication": {
+          "clients": [
+            {
+              "password-file": "/tmp/pwd",
+            }
+          ],
+          "type": "basic",
+        },
+        "socket-port": 8053,
+      },
+    ],
   },
 })");
     testParser(txt, D2ParserContext::PARSER_DHCPDDNS, false);
@@ -871,7 +886,12 @@ TEST_F(TrailingCommasTest, tests) {
     addLog("<string>:14.8");
     addLog("<string>:22.45");
     addLog("<string>:23.8");
-    addLog("<string>:25.4");
+    addLog("<string>:32.42");
+    addLog("<string>:35.26");
+    addLog("<string>:37.28");
+    addLog("<string>:38.8");
+    addLog("<string>:39.6");
+    addLog("<string>:40.4");
     EXPECT_TRUE(checkFile());
 
     // Test with many consecutive commas.
@@ -879,6 +899,52 @@ TEST_F(TrailingCommasTest, tests) {
     testParser(txt, D2ParserContext::PARSER_DHCPDDNS, false);
 }
 
+/// @brief Tests control socket config conflicts.
+TEST(ParserTest, duplicateControlSocket) {
+    // Valid configuration.
+    string txt(R"({
+    "DhcpDdns": {
+        "control-socket": {
+            "socket-type": "http",
+            "socket-address": "127.0.0.1"
+        }
+     }
+})");
+    testParser(txt, D2ParserContext::PARSER_DHCPDDNS, false);
+
+    // Invalid configuration: both map and list.
+    string bad1(R"({
+    "DhcpDdns": {
+        "control-socket": {
+            "socket-type": "http",
+            "socket-address": "127.0.0.1"
+        },
+        "control-sockets": [ ]
+     }
+})");
+
+    ASSERT_NO_THROW(Element::fromJSON(bad1, true));
+    D2ParserContext ctx1;
+    EXPECT_THROW(ctx1.parseString(bad1, D2ParserContext::PARSER_DHCPDDNS),
+                 D2ParseError);
+
+    // Invalid configuration: both name and address.
+    string bad2(R"({
+    "DhcpDdns": {
+        "control-socket": {
+            "socket-type": "http",
+            "socket-address": "127.0.0.1",
+            "socket-name": "::1"
+        }
+     }
+})");
+
+    ASSERT_NO_THROW(Element::fromJSON(bad1, true));
+    D2ParserContext ctx2;
+    EXPECT_THROW(ctx2.parseString(bad2, D2ParserContext::PARSER_DHCPDDNS),
+                 D2ParseError);
+}
+
 }  // namespace test
 }  // namespace d2
 }  // namespace isc
