@@ -910,10 +910,21 @@ public:
 TEST_F(TrailingCommasTest, tests) {
     string txt(R"({
   "Dhcp6": {
-    "control-socket": {
-      "socket-name": "/tmp/kea-dhcp6-ctrl.sock",
-      "socket-type": "unix",
-    },
+    "control-sockets": [
+      {
+        "socket-type": "http",
+        "socket-address": "::1",
+        "authentication": {
+          "clients": [
+            {
+              "password-file": "/tmp/pwd",
+            }
+          ],
+          "type": "basic",
+        },
+        "socket-port": 8000,
+      },
+    ],
     "hooks-libraries": [
       {
         "library": "/usr/local/lib/kea/hooks/libdhcp_dummy.so",
@@ -961,22 +972,25 @@ TEST_F(TrailingCommasTest, tests) {
 })");
     testParser(txt, Parser6Context::PARSER_DHCP6, false);
 
-    addLog("<string>:5.28");
-    addLog("<string>:9.63");
-    addLog("<string>:10.8");
-    addLog("<string>:14.15");
-    addLog("<string>:15.8");
-    addLog("<string>:20.24");
-    addLog("<string>:28.31");
-    addLog("<string>:29.12");
-    addLog("<string>:31.28");
-    addLog("<string>:32.8");
-    addLog("<string>:43.38");
-    addLog("<string>:44.12");
-    addLog("<string>:47.16");
-    addLog("<string>:48.8");
-    addLog("<string>:49.6");
-    addLog("<string>:50.4");
+    addLog("<string>:10.42");
+    addLog("<string>:13.26");
+    addLog("<string>:15.28");
+    addLog("<string>:16.8");
+    addLog("<string>:20.63");
+    addLog("<string>:21.8");
+    addLog("<string>:25.15");
+    addLog("<string>:26.8");
+    addLog("<string>:31.24");
+    addLog("<string>:39.31");
+    addLog("<string>:40.12");
+    addLog("<string>:42.28");
+    addLog("<string>:43.8");
+    addLog("<string>:54.38");
+    addLog("<string>:55.12");
+    addLog("<string>:58.16");
+    addLog("<string>:59.8");
+    addLog("<string>:60.6");
+    addLog("<string>:61.4");
     EXPECT_TRUE(checkFile());
 
     // Test with many consecutive commas.
@@ -984,6 +998,52 @@ TEST_F(TrailingCommasTest, tests) {
     testParser(txt, Parser6Context::PARSER_DHCP6, false);
 }
 
+/// @brief Tests control socket config conflicts.
+TEST(ParserTest, duplicateControlSocket) {
+    // Valid configuration.
+    string txt(R"({
+    "Dhcp6": {
+        "control-socket": {
+            "socket-type": "http",
+            "socket-address": "::1"
+        }
+     }
+})");
+    testParser(txt, Parser6Context::PARSER_DHCP6, false);
+
+    // Invalid configuration: both map and list.
+    string bad1(R"({
+    "Dhcp6": {
+        "control-socket": {
+            "socket-type": "http",
+            "socket-address": "::1"
+        },
+        "control-sockets": [ ]
+     }
+})");
+
+    ASSERT_NO_THROW(Element::fromJSON(bad1, true));
+    Parser6Context ctx1;
+    EXPECT_THROW(ctx1.parseString(bad1, Parser6Context::PARSER_DHCP6),
+                 Dhcp6ParseError);
+
+    // Invalid configuration: both name and address.
+    string bad2(R"({
+    "Dhcp6": {
+        "control-socket": {
+            "socket-type": "http",
+            "socket-address": "::1",
+            "socket-name": "127.0.0.1"
+        }
+     }
+})");
+
+    ASSERT_NO_THROW(Element::fromJSON(bad1, true));
+    Parser6Context ctx2;
+    EXPECT_THROW(ctx2.parseString(bad2, Parser6Context::PARSER_DHCP6),
+                 Dhcp6ParseError);
+}
+
 }  // namespace test
 }  // namespace dhcp
 }  // namespace isc
