@@ -38,12 +38,14 @@ unordered_set<string> CommandCreator::ha_commands6_ = {
 };
 
 ConstElementPtr
-CommandCreator::createDHCPDisable(const unsigned int origin,
+CommandCreator::createDHCPDisable(const unsigned int origin_id,
                                   const unsigned int max_period,
                                   const HAServerType& server_type) {
     ElementPtr args;
     args = Element::createMap();
-    args->set("origin", Element::create(origin));
+    args->set("origin-id", Element::create(origin_id));
+    // Add for backward compatibility with Kea 2.4.0 and earlier.
+    args->set("origin", Element::create("ha-partner"));
     // max-period is optional. A value of 0 means that it is not specified.
     if (max_period > 0) {
         args->set("max-period", Element::create(static_cast<long int>(max_period)));
@@ -54,11 +56,13 @@ CommandCreator::createDHCPDisable(const unsigned int origin,
 }
 
 ConstElementPtr
-CommandCreator::createDHCPEnable(const unsigned int origin,
+CommandCreator::createDHCPEnable(const unsigned int origin_id,
                                  const HAServerType& server_type) {
     ElementPtr args;
     args = Element::createMap();
-    args->set("origin", Element::create(origin));
+    args->set("origin-id", Element::create(origin_id));
+    // Add for backward compatibility with Kea 2.4.0 and earlier.
+    args->set("origin", Element::create("ha-partner"));
     ConstElementPtr command = config::createCommand("dhcp-enable", args);
     insertService(command, server_type);
     return (command);
@@ -140,14 +144,22 @@ CommandCreator::createLease4GetPage(const Lease4Ptr& last_lease4,
 ConstElementPtr
 CommandCreator::createLease6BulkApply(const Lease6CollectionPtr& leases,
                                       const Lease6CollectionPtr& deleted_leases) {
+    ElementPtr leases_list = Element::createList();
     ElementPtr deleted_leases_list = Element::createList();
     for (auto const& lease : *deleted_leases) {
         ElementPtr lease_as_json = lease->toElement();
         insertLeaseExpireTime(lease_as_json);
-        deleted_leases_list->add(lease_as_json);
+        // If the deleted lease is in the released state it means that it
+        // should be preserved in the database. It is treated as released
+        // but can be re-allocated to the same client later (lease affinity).
+        // Such a lease should be updated by the partner rather than deleted.
+        if (lease->state_ == Lease6::STATE_RELEASED) {
+            leases_list->add(lease_as_json);
+        } else {
+            deleted_leases_list->add(lease_as_json);
+        }
     }
 
-    ElementPtr leases_list = Element::createList();
     for (auto const& lease : *leases) {
         ElementPtr lease_as_json = lease->toElement();
         insertLeaseExpireTime(lease_as_json);
@@ -257,12 +269,17 @@ CommandCreator::createMaintenanceNotify(const std::string& server_name,
 }
 
 ConstElementPtr
-CommandCreator::createSyncCompleteNotify(const unsigned int origin,
+CommandCreator::createSyncCompleteNotify(const unsigned int origin_id,
                                          const std::string& server_name,
                                          const HAServerType& server_type) {
     auto args = Element::createMap();
     args->set("server-name", Element::create(server_name));
-    args->set("origin", Element::create(origin));
+    args->set("origin-id", Element::create(origin_id));
+    // Add for backward compatibility with Kea 2.5.5 to Kea 2.5.7.
+    // The origin parameter was introduced for this command in Kea 2.5.5 but
+    // renamed to origin-id to be consistent with the origin-id used in
+    // dhcp-enable and dhcp-disable commands starting from Kea 2.5.8.
+    args->set("origin", Element::create(origin_id));
     auto command = config::createCommand("ha-sync-complete-notify", args);
     insertService(command, server_type);
     return (command);
