@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -25,7 +25,6 @@
 #include <boost/shared_ptr.hpp>
 
 #include <functional>
-#include <map>
 #include <mutex>
 #include <set>
 #include <string>
@@ -123,6 +122,22 @@ private:
     void setPartnerStateInternal(const std::string& state);
 
 public:
+
+    /// @brief Returns the duration since the partner was first seen in the
+    /// current state.
+    ///
+    /// @return A duration since the partner has been in the current state.
+    boost::posix_time::time_duration getDurationSincePartnerStateTime() const;
+
+private:
+
+    /// @brief Sets partner's state time to current time.
+    ///
+    /// It marks the time when the partner was first seen in the current state.
+    void setCurrentPartnerStateTimeInternal();
+
+public:
+
     /// @brief Returns scopes served by the partner server.
     ///
     /// @return A set of scopes served by the partner.
@@ -682,6 +697,17 @@ private:
     /// the partner.
     void setPartnerUnsentUpdateCountInternal(uint64_t unsent_update_count);
 
+public:
+    /// @brief Retrieves the time of the local node when skew was last calculated.
+    ///
+    /// @return my time at skew
+    boost::posix_time::ptime getMyTimeAtSkew() const;
+
+    /// @brief Retrieves the time of the partner node when skew was last calculated.
+    ///
+    /// @return partner's time at skew
+    boost::posix_time::ptime getPartnerTimeAtSkew() const;
+
 protected:
     /// @brief Pointer to the common IO service instance.
     asiolink::IOServicePtr io_service_;
@@ -706,6 +732,9 @@ protected:
     /// Negative value means that the partner's state is unknown.
     int partner_state_;
 
+    /// Holds a time when partner was first seen in the current state.
+    boost::posix_time::ptime partner_state_time_;
+
     /// @brief Last known set of scopes served by the partner server.
     std::set<std::string> partner_scopes_;
 
