@@ -10,7 +10,7 @@
 #include <ha_log.h>
 #include <ha_service_states.h>
 #include <cc/dhcp_config_error.h>
-#include <util/file_utilities.h>
+#include <util/filesystem.h>
 #include <boost/make_shared.hpp>
 #include <limits>
 #include <set>
@@ -104,8 +104,8 @@ HAConfigParser::parseAll(const HAConfigMapperPtr& config_storage,
     if (config_vec.empty()) {
         isc_throw(ConfigError, "a list of HA configurations must not be empty");
     }
-    for (auto const& config : config_vec) {
-        parseOne(config_storage, config);
+    for (auto const& cfg : config_vec) {
+        parseOne(config_storage, cfg);
     }
 }
 
