@@ -14,7 +14,7 @@
 #include <config/command_mgr.h>
 #include <http/response.h>
 #include <http/response_parser.h>
-#include <http/tests/test_http_client.h>
+#include <http/testutils/test_http_client.h>
 #include <util/multi_threading_mgr.h>
 #include <testutils/gtest_utils.h>
 
@@ -81,11 +81,7 @@ public:
         }
 
         test_timer_.cancel();
-        io_service_->restart();
-        try {
-            io_service_->poll();
-        } catch (...) {
-        }
+        io_service_->stopAndPoll();
 
         // Deregisters commands.
         config::CommandMgr::instance().deregisterAll();
@@ -198,7 +194,7 @@ public:
         // Loop until the clients are done, an error occurs, or the time runs out.
         size_t num_done = 0;
         while (num_done != request_limit) {
-            // Always call restart() before we call run();
+            io_service_->stop();
             io_service_->restart();
 
             // Run until a client stops the service.
@@ -219,8 +215,7 @@ public:
     /// @param response_str a string containing the whole HTTP
     /// response received.
     ///
-    /// @return An HttpResponse constructed from by parsing the
-    /// response string.
+    /// @return An HttpResponse constructed by parsing the response string.
     HttpResponsePtr parseResponse(const std::string response_str) {
         HttpResponsePtr hr(new HttpResponse());
         HttpResponseParser parser(*hr);
