@@ -57,6 +57,8 @@ extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_NCR_SENT;
 extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_SENDER_STARTED;
 extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_SENDER_STOPPED;
 extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_SUSPEND_UPDATES;
+extern const isc::log::MessageID DHCPSRV_EVAL_ERROR;
+extern const isc::log::MessageID DHCPSRV_EVAL_RESULT;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE4_RECOVER_SKIP;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE4_RENEW_SKIP;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE4_SELECT_SKIP;
@@ -259,6 +261,8 @@ extern const isc::log::MessageID DHCPSRV_SUBNET4_SELECT_NO_USABLE_ADDRESS;
 extern const isc::log::MessageID DHCPSRV_SUBNET6_SELECT_BY_ADDRESS_NO_MATCH;
 extern const isc::log::MessageID DHCPSRV_SUBNET6_SELECT_BY_INTERFACE_ID_NO_MATCH;
 extern const isc::log::MessageID DHCPSRV_SUBNET6_SELECT_BY_INTERFACE_NO_MATCH;
+extern const isc::log::MessageID DHCPSRV_TEMPLATE_EVAL_ERROR;
+extern const isc::log::MessageID DHCPSRV_TEMPLATE_EVAL_RESULT;
 extern const isc::log::MessageID DHCPSRV_TIMERMGR_CALLBACK_FAILED;
 extern const isc::log::MessageID DHCPSRV_TIMERMGR_REGISTER_TIMER;
 extern const isc::log::MessageID DHCPSRV_TIMERMGR_RUN_TIMER_OPERATION;
