@@ -30,6 +30,7 @@
 #include <cc/data.h>
 #include <cc/user_context.h>
 #include <cc/simple_parser.h>
+#include <config/http_command_config.h>
 #include <util/optional.h>
 #include <util/str.h>
 
@@ -530,18 +531,32 @@ public:
         return (cfg_mac_source_);
     }
 
-    /// @brief Returns information about control socket
+    /// @brief Returns information about UNIX control socket
     ///
-    /// @return pointer to the Element that holds control-socket map
+    /// @return pointer to the UNIX control socket config
     const isc::data::ConstElementPtr getControlSocketInfo() const {
-        return (control_socket_);
+        return (unix_control_socket_);
     }
 
-    /// @brief Sets information about the control socket
+    /// @brief Sets information about the UNIX control socket
     ///
-    /// @param control_socket Element that holds control-socket map
+    /// @param control_socket UNIX control socket config
     void setControlSocketInfo(const isc::data::ConstElementPtr& control_socket) {
-        control_socket_ = control_socket;
+        unix_control_socket_ = control_socket;
+    }
+
+    /// @brief Returns information about HTTP/HTTPS control socket
+    ///
+    /// @return pointer to the HTTP/HTTPS control socket config
+    isc::config::HttpCommandConfigPtr getHttpControlSocketInfo() const {
+        return (http_control_socket_);
+    }
+
+    /// @brief Sets information about the HTTP/HTTPS control socket
+    ///
+    /// @param control_socket HTTP/HTTPS control socket config
+    void setHttpControlSocketInfo(const isc::config::HttpCommandConfigPtr& control_socket) {
+        http_control_socket_ = control_socket;
     }
 
     /// @brief Returns DHCP queue control information
@@ -897,7 +912,8 @@ public:
         ignore_dhcp_server_identifier_ = false;
         ignore_rai_link_selection_ = false;
         exclude_first_last_24_ = false;
-        control_socket_.reset();
+        unix_control_socket_.reset();
+        http_control_socket_.reset();
         d2_client_config_.reset(new D2ClientConfig());
         cfg_expiration_.reset(new CfgExpiration());
         dhcp_multi_threading_.reset();
@@ -935,31 +951,6 @@ public:
     void sanityChecksLifetime(const SrvConfig& target_config,
                               const std::string& name) const;
 
-    /// @brief Moves deprecated parameters from dhcp-ddns element to global element
-    ///
-    /// Given a server configuration element map, the following parameters are moved
-    /// from dhcp-ddns to top-level (i.e. global) element if they do not already
-    /// exist there:
-    ///
-    /// @code
-    /// From dhcp-ddns:            To (global):
-    /// ------------------------------------------------------
-    /// override-no-update         ddns-override-no-update
-    /// override-client-update     ddns-override-client-update
-    /// replace-client-name        ddns-replace-client-name
-    /// generated-prefix           ddns-generated-prefix
-    /// qualifying-suffix          ddns-qualifying-suffix
-    /// hostname-char-set          hostname-char-set
-    /// hostname-char-replacement  hostname-char-replacement
-    /// @endcode
-    ///
-    /// Note that the whether or not the deprecated parameters are added
-    /// to the global element, they are always removed from the dhcp-ddns
-    /// element.
-    ///
-    /// @param srv_elem server top level map to alter
-    static void moveDdnsParams(isc::data::ElementPtr srv_elem);
-
     /// @brief Configures the server to allow or disallow specifying multiple
     /// hosts with the same IP address/subnet.
     ///
@@ -1200,8 +1191,11 @@ private:
     /// DHCPv6.
     CfgHostOperationsPtr cfg_host_operations6_;
 
-    /// @brief Pointer to the control-socket information
-    isc::data::ConstElementPtr control_socket_;
+    /// @brief Pointer to the UNIX control socket configuration
+    isc::data::ConstElementPtr unix_control_socket_;
+
+    /// @brief Pointer to the HTTP/HTTPS control socket configuration
+    isc::config::HttpCommandConfigPtr http_control_socket_;
 
     /// @brief Pointer to the dhcp-queue-control information
     isc::data::ConstElementPtr dhcp_queue_control_;
